// Bot Commander V7 - Epic Enhanced JavaScript

document.addEventListener('DOMContentLoaded', function() {
    const riskSlider = document.getElementById('risk-slider');
    const roiDisplay = document.getElementById('roi-display');
    const riskWarning = document.getElementById('risk-warning');
    const riskIcons = document.querySelectorAll('.risk-icon');
    
    // Risk level configuration
    const riskLevels = {
        1: { roi: '2%', warning: false, color: '#2ecc71' },
        2: { roi: '5%', warning: false, color: '#3498db' },
        3: { roi: '12%', warning: false, color: '#f39c12' },
        4: { roi: '25%', warning: true, color: '#e74c3c' },
        5: { roi: '50%', warning: true, color: '#9b59b6' }
    };
    
    function updateRiskLevel(level) {
        const config = riskLevels[level];
        
        // Update ROI display
        roiDisplay.textContent = config.roi;
        roiDisplay.style.background = config.color;
        
        // Show/hide warning
        if (config.warning) {
            riskWarning.style.display = 'block';
        } else {
            riskWarning.style.display = 'none';
        }
        
        // Update active icon
        riskIcons.forEach((icon, index) => {
            if (index === level - 1) {
                icon.classList.add('active');
            } else {
                icon.classList.remove('active');
            }
        });
        
        // Add gradient glow effect to slider thumb based on risk level
        const slider = document.getElementById('risk-slider');
        slider.style.filter = `drop-shadow(0 0 8px ${config.color}40)`;
    }
    
    // Risk slider event listener
    if (riskSlider) {
        riskSlider.addEventListener('input', function() {
            const level = parseInt(this.value);
            updateRiskLevel(level);
        });
        
        // Initialize with current value
        updateRiskLevel(parseInt(riskSlider.value));
    }
    
    // Risk icon click handlers
    riskIcons.forEach((icon, index) => {
        icon.addEventListener('click', function() {
            const level = index + 1;
            riskSlider.value = level;
            updateRiskLevel(level);
        });
    });
    
    // Add bot functionality
    const addBotBtn = document.querySelector('.add-bot');
    const botSlots = document.getElementById('bot-slots');
    
    if (addBotBtn) {
        addBotBtn.addEventListener('click', function() {
            const emptySlot = document.querySelector('.bot-card.empty');
            if (emptySlot) {
                const botAllocation = document.querySelector('.add-bot-controls input').value;
                const riskLevel = parseInt(riskSlider.value);
                const botNames = [
                    'Stable Climber', 'Trend Rider', 'Momentum Beast', 
                    'Hype Chaser', 'Degen Rocket'
                ];
                
                emptySlot.classList.remove('empty');
                emptySlot.classList.add('running');
                emptySlot.innerHTML = `
                    <div class="bot-name">${botNames[riskLevel - 1]}</div>
                    <div class="bot-allocation">$${botAllocation}</div>
                    <div class="bot-pnl up">+$0.00 (0%)</div>
                    <button class="run-bot">▶</button>
                    <button class="remove-bot">✖</button>
                `;
                
                // Add event listeners to new buttons
                const runBtn = emptySlot.querySelector('.run-bot');
                const removeBtn = emptySlot.querySelector('.remove-bot');
                
                runBtn.addEventListener('click', function() {
                    // Toggle bot running state
                    console.log('Toggle bot running state');
                });
                
                removeBtn.addEventListener('click', function() {
                    emptySlot.classList.add('empty');
                    emptySlot.classList.remove('running');
                    emptySlot.innerHTML = '<div class="bot-name">Load Bot</div>';
                });
                
                // Shimmer effect
                addBotBtn.classList.add('shimmer');
                setTimeout(() => {
                    addBotBtn.classList.remove('shimmer');
                }, 2000);
            }
        });
    }
    
    // Initialize existing remove button handlers
    document.querySelectorAll('.remove-bot').forEach(btn => {
        btn.addEventListener('click', function() {
            const botCard = this.closest('.bot-card');
            botCard.classList.add('empty');
            botCard.classList.remove('running');
            botCard.innerHTML = '<div class="bot-name">Load Bot</div>';
        });
    });
    
    // AI Avatar interaction
    const aiInput = document.querySelector('#ai-avatar input');
    const speechBubble = document.querySelector('.speech-bubble');
    
    if (aiInput) {
        aiInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                const message = this.value.trim();
                if (message) {
                    // Simulate AI response
                    speechBubble.textContent = `Analyzing "${message}"... Let me help you optimize your trading strategy!`;
                    this.value = '';
                    
                    // Reset after 3 seconds
                    setTimeout(() => {
                        speechBubble.textContent = "Hey legend. You've got $2,000 in demo. Let's find your first bot.";
                    }, 3000);
                }
            }
        });
    }
    
    // Balance animation effect
    const balanceAmount = document.querySelector('.balance-amount');
    if (balanceAmount) {
        setInterval(() => {
            // Simulate small balance changes
            const currentBalance = parseFloat(balanceAmount.textContent.replace('$', '').replace(',', ''));
            const change = (Math.random() - 0.5) * 10; // Random change -5 to +5
            const newBalance = currentBalance + change;
            balanceAmount.textContent = `$${newBalance.toLocaleString('en-US', {minimumFractionDigits: 2, maximumFractionDigits: 2})}`;
        }, 5000);
    }
    
    // Console log for debugging
    console.log('Bot Commander V7 - Epic Enhanced initialized');
    console.log('Gradient risk slider with 5 levels loaded');
});